@@ -1,11 +1,13 @@
 """KnackSlueth - Find usages of data objects in Knack app metadata."""
 
+__version__ = "0.1.15"
+
 from knack_sleuth.models import (
     Application,
     Connection,
     Connections,
     HomeScene,
-    KnackAppExport,
+    KnackAppMetadata,
     KnackField,
     KnackObject,
     Scene,
@@ -15,11 +17,12 @@ from knack_sleuth.models import (
 from knack_sleuth.sleuth import KnackSleuth, Usage
 
 __all__ = [
+    "__version__",
     "Application",
     "Connection",
     "Connections",
     "HomeScene",
-    "KnackAppExport",
+    "KnackAppMetadata",
     "KnackField",
     "KnackObject",
     "KnackSleuth",
